# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account_bank_statement
from . import account_payment
from . import account_journal
from . import account_tax
from . import account_move
from . import barcode_rule
from . import chart_template
from . import digest
from . import pos_category
from . import pos_config
from . import pos_order
from . import pos_session
from . import product
from . import res_partner
from . import res_company
from . import res_config_settings
from . import stock_picking
from . import stock_rule
from . import stock_warehouse
from . import pos_payment
from . import pos_payment_method
from . import pos_bill
